@@ -133,10 +133,7 @@ class UriTest extends TestCase
 
     public function testWithHostValidObject()
     {
-        $mock = $this->getMockBuilder(stdClass::class)->addMethods(['__toString'])->getMock();
-        $mock->expects($this->once())
-            ->method('__toString')
-            ->will($this->returnValue('host.test'));
+        $mock = new StringableTestObject('host.test');
 
         $uri = $this->uriFactory()->withHost($mock);
         $this->assertEquals('host.test', $uri->getHost());
@@ -298,10 +295,7 @@ class UriTest extends TestCase
 
     public function testWithQueryValidObject()
     {
-        $mock = $this->getMockBuilder(stdClass::class)->addMethods(['__toString'])->getMock();
-        $mock->expects($this->once())
-            ->method('__toString')
-            ->will($this->returnValue('xyz=123'));
+        $mock = new StringableTestObject('xyz=123');
 
         $uri = $this->uriFactory()->withQuery($mock);
         $this->assertEquals('xyz=123', $uri->getQuery());
@@ -350,10 +344,7 @@ class UriTest extends TestCase
 
     public function testWithFragmentValidObject()
     {
-        $mock = $this->getMockBuilder(stdClass::class)->addMethods(['__toString'])->getMock();
-        $mock->expects($this->once())
-            ->method('__toString')
-            ->will($this->returnValue('other-fragment'));
+        $mock = new StringableTestObject('other-fragment');
 
         $uri = $this->uriFactory()->withFragment($mock);
         $this->assertEquals('other-fragment', $uri->getFragment());
